@@ -56,11 +56,12 @@ const PropertiesDialog = new Lang.Class({
                                         transient_for: toplevel,
                                         modal: true,
                                         destroy_with_parent: true,
+                                        use_header_bar: true,
                                         default_width: 400,
                                         title: _("Properties"),
                                         hexpand: true });
-        this.widget.add_button(_("Done"), Gtk.ResponseType.OK);
-        this.widget.set_default_response(Gtk.ResponseType.OK);
+        this.widget.add_button(_("Done"), Gtk.ResponseType.CLOSE);
+        this.widget.set_default_response(Gtk.ResponseType.CLOSE);
 
         let grid = new Gtk.Grid ({ orientation: Gtk.Orientation.VERTICAL,
                                    row_homogeneous: true,
@@ -177,7 +178,7 @@ const PropertiesDialog = new Lang.Class({
                                                     halign: Gtk.Align.START });
         } else if (doc instanceof Documents.SkydriveDocument) {
             this._sourceData = new Gtk.LinkButton({ label: doc.sourceName,
-                                                    uri: 'https://skydrive.live.com',
+                                                    uri: 'https://onedrive.live.com',
                                                     halign: Gtk.Align.START });
         } else { // local document
             if (doc.collection) {
