@@ -633,6 +633,7 @@ const OrganizeCollectionDialog = new Lang.Class({
         this.widget = new Gtk.Dialog({ transient_for: toplevel,
                                        modal: true,
                                        destroy_with_parent: true,
+                                       use_header_bar: true,
                                        default_width: 400,
                                        default_height: 250,
         // Translators: "Collections" refers to documents in this context
@@ -922,10 +923,8 @@ const SelectionToolbar = new Lang.Class({
 
        dialog.widget.connect('response', Lang.bind(this,
            function(widget, response) {
-               if (response == Gtk.ResponseType.OK) {
-                   dialog.widget.destroy();
-                   Application.selectionController.setSelectionMode(false);
-               }
+               dialog.widget.destroy();
+               Application.selectionController.setSelectionMode(false);
            }));
     },
 
